@@ -156,14 +156,12 @@ class DataPattern(Data):
             + linesep
             + str(self.rebuild_indices).replace(linesep, linesep + "\t")
             + linesep
-            + linesep
         )
         DataPattern_str += (
             "unique_indices = "
             + linesep
             + str(self.unique_indices).replace(linesep, linesep + "\t")
             + linesep
-            + linesep
         )
         DataPattern_str += "is_step = " + str(self.is_step) + linesep
         DataPattern_str += (
@@ -193,9 +191,9 @@ class DataPattern(Data):
         # Check the properties inherited from Data
         if not super(DataPattern, self).__eq__(other):
             return False
-        if not array_equal(other.rebuild_indices, self.rebuild_indices):
+        if other.rebuild_indices != self.rebuild_indices:
             return False
-        if not array_equal(other.unique_indices, self.unique_indices):
+        if other.unique_indices != self.unique_indices:
             return False
         if other.is_step != self.is_step:
             return False
@@ -214,14 +212,12 @@ class DataPattern(Data):
 
         # Get the properties inherited from Data
         DataPattern_dict = super(DataPattern, self).as_dict()
-        if self.rebuild_indices is None:
-            DataPattern_dict["rebuild_indices"] = None
-        else:
-            DataPattern_dict["rebuild_indices"] = self.rebuild_indices.tolist()
-        if self.unique_indices is None:
-            DataPattern_dict["unique_indices"] = None
-        else:
-            DataPattern_dict["unique_indices"] = self.unique_indices.tolist()
+        DataPattern_dict["rebuild_indices"] = (
+            self.rebuild_indices.copy() if self.rebuild_indices is not None else None
+        )
+        DataPattern_dict["unique_indices"] = (
+            self.unique_indices.copy() if self.unique_indices is not None else None
+        )
         DataPattern_dict["is_step"] = self.is_step
         if self.values is None:
             DataPattern_dict["values"] = None
@@ -260,13 +256,8 @@ class DataPattern(Data):
     def _set_rebuild_indices(self, value):
         """setter of rebuild_indices"""
         if type(value) is int and value == -1:
-            value = array([])
-        elif type(value) is list:
-            try:
-                value = array(value)
-            except:
-                pass
-        check_var("rebuild_indices", value, "ndarray")
+            value = list()
+        check_var("rebuild_indices", value, "list")
         self._rebuild_indices = value
 
     rebuild_indices = property(
@@ -274,7 +265,7 @@ class DataPattern(Data):
         fset=_set_rebuild_indices,
         doc=u"""Indices to rebuild complete axis
 
-        :Type: ndarray
+        :Type: list
         """,
     )
 
@@ -285,13 +276,8 @@ class DataPattern(Data):
     def _set_unique_indices(self, value):
         """setter of unique_indices"""
         if type(value) is int and value == -1:
-            value = array([])
-        elif type(value) is list:
-            try:
-                value = array(value)
-            except:
-                pass
-        check_var("unique_indices", value, "ndarray")
+            value = list()
+        check_var("unique_indices", value, "list")
         self._unique_indices = value
 
     unique_indices = property(
@@ -299,7 +285,7 @@ class DataPattern(Data):
         fset=_set_unique_indices,
         doc=u"""Indices which were taken from complete axis
 
-        :Type: ndarray
+        :Type: list
         """,
     )
 
