@@ -1,6 +1,3 @@
-from copy import deepcopy
-
-
 def copy(self):
     """Return a copy of the class"""
-    return deepcopy(self)
+    return type(self)(init_dict=self.as_dict())
