@@ -1,10 +1,12 @@
 # -*- coding: utf-8 -*-
 from SciDataTool.Functions import NormError, UnitError
-from SciDataTool.Functions.conversions import convert, to_dB, to_dBA
+from SciDataTool.Functions.conversions import convert, to_dB, to_dBA, to_noct
 from numpy import apply_along_axis, abs as np_abs
 
 
-def get_magnitude_along(self, *args, unit="SI", is_norm=False, axis_data=[]):
+def get_magnitude_along(
+    self, *args, unit="SI", is_norm=False, axis_data=[], is_squeeze=True
+):
     """Returns the ndarray of the magnitude of the FT, using conversions and symmetries if needed.
     Parameters
     ----------
@@ -24,10 +26,19 @@ def get_magnitude_along(self, *args, unit="SI", is_norm=False, axis_data=[]):
     """
     if len(args) == 1 and type(args[0]) == tuple:
         args = args[0]  # if called from another script with *args
-    return_dict = self.get_along(args, axis_data=axis_data)
+    return_dict = self.get_along(args, axis_data=axis_data, is_squeeze=is_squeeze)
     values = return_dict[self.symbol]
     # Compute magnitude
     values = np_abs(values)
+    # 1/nth octave band
+    for axis in return_dict["axes_list"]:
+        if axis.name == "freqs" or axis.corr_name == "freqs":
+            index = axis.index
+            if axis.noct is not None:
+                (values, foct) = apply_along_axis(
+                    to_noct, index, values, return_dict["freqs"], noct=axis.noct
+                )
+                return_dict[axis.name] = foct
     # Convert into right unit (apart because of dBA conversion)
     if unit == self.unit or unit == "SI":
         if is_norm:
