@@ -6,7 +6,7 @@ from SciDataTool.Functions.interpolations import (
 from numpy import apply_along_axis, squeeze
 
 
-def interpolate(self, values, axes_list):
+def interpolate(self, values, axes_list, is_squeeze=True):
     """Returns the values of the field interpolated over the axes values.
     Parameters
     ----------
@@ -26,12 +26,18 @@ def interpolate(self, values, axes_list):
     for axis_requested in axes_list:
         if axis_requested.input_data is not None:
             if axis_requested.is_step:
-                values = apply_along_axis(
-                    get_interpolation_step,
-                    axis_requested.index,
+                # values = apply_along_axis(
+                #     get_interpolation_step,
+                #     axis_requested.index,
+                #     values,
+                #     axis_requested.values,
+                #     axis_requested.input_data,
+                # )
+                values = get_interpolation_step(
                     values,
                     axis_requested.values,
                     axis_requested.input_data,
+                    axis_requested.index,
                 )
             else:
                 values = get_interpolation(
@@ -42,4 +48,6 @@ def interpolate(self, values, axes_list):
                 )
             # Store new axis data into axis_requested.values
             axis_requested.values = axis_requested.input_data
-    return squeeze(values)
+    if is_squeeze:
+        values = squeeze(values)
+    return values
